@@ -12,8 +12,14 @@ def write_list_as_json_str(fields_json, rows):
         for r in rows:
             for field_json in fields_json:
                 if r[field_json] is not None:
-                    r[field_json] = json.loads(r[field_json])
-    return "\n".join([json.dumps(dict(r), default=myconverter) or "{}" for r in rows])
+                    try:
+                        r[field_json] = json.loads(r[field_json])
+                    except TypeError:
+                        continue
+    try:
+        return "\n".join([json.dumps(dict(r), default=myconverter) or "{}" for r in rows])
+    except (ValueError, TypeError):
+        return "\n".join([dict(r) or "{}" for r in rows])
 
 
 def vertica_insert(cursor, target, fields, fields_json, data):
